@@ -13,7 +13,7 @@
 ##############################################################################
 """Pluggable Authentication Service Tests
 
-$Id: tests.py 102984 2009-08-20 08:30:43Z nadako $
+$Id: tests.py 108827 2010-02-06 11:16:44Z trollfot $
 """
 __docformat__ = "reStructuredText"
 
@@ -34,7 +34,7 @@ from zope.session.session import \
 from zope.session.http import CookieClientIdManager
 
 from zope.publisher import base
-from zope.app.authentication.session import SessionCredentialsPlugin
+from zope.pluggableauth.plugins.session import SessionCredentialsPlugin
 
 
 class TestClientId(object):
